#82
Factorial sum
- 시간 제한
- 1s
- 메모리 제한
- 256MB
- 제출
- 90
- 정답
- 14
- 맞힌 사람
- 12
- 정답 비율
- 13.6%
문제
이라고 하자, 두 정수 가 주어졌을 때 의 값을 구해보자
단, 수가 엄청 크기 때문에 로 나눈 나머지를 구해보자. 나머지 연산의 성질에 의해 모든 답을 계산한 후에 로 나눌 필요 없이, 일반적으로는 계산할 때마다 바로바로 나머지 연산을 적용한다.
입력
첫째 줄에 정수 가 공백으로 구분되어 주어진다.
출력
를 로 나눈 나머지를 출력한다.
예제 입력
2 4
예제 출력
54
- 알고리즘 분류
코드 제출
코드를 제출하려면 로그인이 필요합니다.
로그인내 제출
제출 내역이 없습니다.
맞은 사람
| # | 순위 | 사용자 | 언어 | 시간 | 메모리 | 코드 길이 | |
|---|---|---|---|---|---|---|---|
| 4094 | 🥇 | 202302602 | C++ | 4ms | 1496KB | 467B | |
| 4123 | 🥈 | 202102702 | C++ | 7ms | 5336KB | 504B | |
| 4155 | 🥉 | 202102622 | C++ | 9ms | 8792KB | 472B | |
| 4285 | 4 | 202503333 | Java | 34ms | 38260KB | 951B | |
| 4419 | 5 | 202102706 | Java | 37ms | 37644KB | 831B | |
| 4119 | 6 | 202500392 | Java | 73ms | 40528KB | 623B | |
| 4582 | 7 | 202500928 | Java | 82ms | 48420KB | 572B | |
| 9557 | 8 | 안우진 | PyPy | 87ms | 69816KB | 212B | |
| 3998 | 9 | 공사판 | Python | 114ms | 9064KB | 221B | |
| 3855 | 10 | 2024ANAGETDON_TESTER | Python | 177ms | 45564KB | 196B | |
| 9007 | 11 | 이재준 | Python | 218ms | 113512KB | 377B | |
| 4654 | 12 | 202503216 | Python | 1329ms | 195592KB | 639B |
난이도 투표
로그인 후 AC 받으면 투표할 수 있습니다.
전체 제출
| # | 사용자 | 문제 | 결과 | 언어 | 시간 | 메모리 | 코드 길이 | 제출 시간 | |
|---|---|---|---|---|---|---|---|---|---|
| 9557 | 맞았습니다 | PyPy | 87ms | 69816KB | 212B | 2026. 07. 19. 14:53 | |||
| 9556 | 틀렸습니다 | PyPy | - | - | 237B | 2026. 07. 19. 14:53 | |||
| 9555 | 틀렸습니다 | PyPy | - | - | 159B | 2026. 07. 19. 14:49 | |||
| 9554 | 틀렸습니다 | PyPy | - | - | 153B | 2026. 07. 19. 14:48 | |||
| 9553 | 런타임 에러 | PyPy | - | - | 149B | 2026. 07. 19. 14:48 | |||
| 9007 | 맞았습니다 | Python | 218ms | 113512KB | 377B | 2026. 06. 14. 07:50 | |||
| 8664 | 시간 초과 | Python | - | - | 312B | 2026. 06. 01. 05:18 | |||
| 4676 | 시간 초과 | Python | - | - | 377B | 2025. 05. 25. 04:55 | |||
| 4671 | 시간 초과 | Python | - | - | 377B | 2025. 05. 25. 04:53 | |||
| 4667 | 시간 초과 | Python | - | - | 367B | 2025. 05. 25. 04:52 | |||
| 4654 | 맞았습니다 | Python | 1329ms | 195592KB | 639B | 2025. 05. 25. 04:36 | |||
| 4652 | 맞았습니다 | Python | 1431ms | 204404KB | 578B | 2025. 05. 25. 04:35 | |||
| 4582 | 맞았습니다 | Java | 82ms | 48420KB | 572B | 2025. 05. 24. 17:37 | |||
| 4578 | 시간 초과 | Java | - | - | 869B | 2025. 05. 24. 16:55 | |||
| 4576 | 런타임 에러 | Java | - | - | 886B | 2025. 05. 24. 16:53 | |||
| 4564 | 시간 초과 | Java | - | - | 992B | 2025. 05. 24. 15:54 | |||
| 4550 | 시간 초과 | Java | - | - | 720B | 2025. 05. 24. 15:27 | |||
| 4541 | 런타임 에러 | Java | - | - | 683B | 2025. 05. 24. 15:19 | |||
| 4539 | 런타임 에러 | Java | - | - | 675B | 2025. 05. 24. 15:17 | |||
| 4536 | 런타임 에러 | Java | - | - | 675B | 2025. 05. 24. 15:11 |